{% extends "announcements/base.html" %} {% load i18n %} {% load url from future %} {% block head_title %}{% trans "Announcements Admin" %}{% endblock %} {% block body_class %}announcements{% endblock %} {% block body %}

## {% trans "Announcements" %}

{% trans "Add New Announcement" %}

{% for announcement in announcement_list %}
{% trans "Edit" %} | {% if announcement.publish_start or announcement.publish_end %} Published from {{ announcement.publish_start|date:"F j, Y" }} to {{ announcement.publish_end|date:"F j, Y" }} {% endif %} | {{ announcement.title }} | {{ announcement.content }}
{% endfor %}

{% endblock %}